<?php

/*********************************
  デバッグ用
 **********************************/
function debug($val)
{
  echo '<pre>';
  var_dump($val);
  echo '</pre>';
}

/*********************************
  アイキャッチ画像を有効にする
 **********************************/
add_theme_support('post-thumbnails');
add_image_size('img_300_200', 300, 200, true);

/*********************************
  titleタグ出力
 **********************************/
add_theme_support('title-tag');
add_filter('document_title_separator', function ($separator) {
  $separator = '|';
  return $separator;
});

/*********************************
  投稿概要文文字数変更
 **********************************/
add_filter('excerpt_mblength', function () {
  return 110;
});

/*********************************
  投稿概要文省略記号変更
 **********************************/
add_filter('excerpt_more', function () {
  return '…';
});

/*********************************
 投稿者アーカイブ非表示リダイレクト
 **********************************/
add_action('template_redirect', function () {
  if (is_author()) {
    wp_redirect(home_url());
    exit;
  }
});

/*********************************
  CSS読み込み
 **********************************/
add_action('wp_enqueue_scripts', function () {
  // カルーセル
  wp_enqueue_style(
    'slick_css',
    'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick.min.css'
  );
  wp_enqueue_style(
    'slick_theme_css',
    'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick-theme.min.css'
  );
  // スクロールアニメーション
  wp_enqueue_style(
    'aos',
    'https://cdnjs.cloudflare.com/ajax/libs/aos/2.3.4/aos.css'
  );
  // 共通CSS
  wp_enqueue_style(
    'common_css',
    get_theme_file_uri('/css/common.css'),
    ['slick_css', 'slick_theme_css', 'aos'],
    filemtime(get_theme_file_path('/css/common.css'))
  );
});

/*********************************
  JS読み込み
 **********************************/
add_action('wp_enqueue_scripts', function () {
  // wp_deregister_script('jquery');
  wp_enqueue_script(
    'jquery',
    'https://code.jquery.com/jquery-3.4.1.min.js',
    [],
    false,
    true
  );
  // カルーセル
  wp_enqueue_script(
    'slick_js',
    'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick.min.js',
    ['jquery'],
    false,
    true
  );
  // スクロールアニメーション
  wp_enqueue_script(
    'aos_js',
    'https://cdnjs.cloudflare.com/ajax/libs/aos/2.3.4/aos.js',
    ['jquery'],
    false,
    true
  );
  // lightBox2
  wp_enqueue_script(
    'lightBox2',
    'https://cdnjs.cloudflare.com/ajax/libs/lightbox2/2.11.3/js/lightbox.min.js',
    ['jquery'],
    false,
    true
  );
  // 共通JS
  wp_enqueue_script(
    'common_js',
    get_theme_file_uri('/js/script.js'),
    ['jquery', 'slick_js', 'aos_js', 'lightBox2'],
    filemtime(get_theme_file_path('/js/script.js')),
    true
  );
});

/*********************************
  スマホでは管理バーを非表示
 **********************************/
if (wp_is_mobile()) {
  add_filter('show_admin_bar', '__return_false');
}

/*********************************
  管理画面用CSS/JS読み込み
 **********************************/
add_action('admin_enqueue_scripts', function () {
  // CSS
  wp_enqueue_style(
    'admin-style',
    get_theme_file_uri('/css/admin.css'),
    [],
    filemtime(get_theme_file_path('/css/admin.css'))
  );
});

/*********************************
  管理画面メニュー非表示
 **********************************/
// add_action('admin_menu', 'remove_admin_menu', 999);
// function remove_admin_menu()
// {
//   // remove_menu_page('index.php');                // ダッシュボード
//   // remove_menu_page('edit.php');                 // 投稿
//   // remove_menu_page('upload.php');               // メディア
//   // remove_menu_page('edit.php?post_type=page');  // 固定ページ
//   // remove_menu_page('edit-comments.php');        // コメント
//   // remove_menu_page('themes.php');               // 外観
//   // remove_menu_page('plugins.php');              // プラグイン
//   // remove_menu_page('users.php');                // ユーザー
//   // remove_menu_page('tools.php');                // ツール
//   // remove_menu_page('options-general.php');      // 設定
// }


/*********************************
  スラッグ名が日本語だったら自動的に投稿タイプ＋id付与へ変更（スラッグを設定した場合は適用しない）
 **********************************/
function auto_post_slug($slug, $post_ID, $post_status, $post_type)
{
  if (preg_match('/(%[0-9a-f]{2})+/', $slug)) {
    $slug = utf8_uri_encode($post_type) . '-' . $post_ID;
  }
  return $slug;
}
add_filter('wp_unique_post_slug', 'auto_post_slug', 10, 4);

/*********************************
 メニュー機能追加
 **********************************/
// メニュー機能を使えるようにする
add_action('init', function () {
  // メニューに位置指定チェックボックス作成
  register_nav_menus([
    'globalMenu-pc' => 'グローバルメニューPC用',
    'globalMenu-sp' => 'グローバルメニュースマホ用',
    'footerMenu' => 'フッターメニュー',
  ]);
});


/*********************************
  ウィジェットエリア作成
 **********************************/
register_sidebar(
  [
    'name' => 'フッターエリア',
    'id' => 'widget1',
    'before_widget' => '<div class="WidgetFooter">',
    'after_widget' => '</div>',
    'before_title' => '<div class="WidgetFooter_mainTitle">',
    'after_title' => '</div>',

  ]
);
register_sidebar(
  [
    'name' => '広告エリア',
    'id' => 'widget2',
    'before_widget' => '<div class="WidgetAd">',
    'after_widget' => '</div>',
    'before_title' => '<div class="WidgetAd_mainTitle">',
    'after_title' => '</div>',
  ]
);

/*********************************
  スラッグをclass名として出力
 **********************************/
function getSlugName()
{
  $post_obj =  $GLOBALS['wp_the_query']->get_queried_object();
  $slug = '';
  if (is_front_page()) {
    $slug = 'top';
    if (is_page() && get_post(get_the_ID())->post_name) {
      $slug = $post_obj->post_name;
    }
  } elseif (is_category()) {
    $slug = 'cat ' . $post_obj->category_nicename;
  } elseif (is_tag()) {
    $slug = 'tag ' . $post_obj->slug;
  } elseif (is_singular()) {
    $slug = $post_obj->post_type . ' ' . $post_obj->post_name;
  } elseif (is_search()) {
    $slug  = $GLOBALS['wp_the_query']->posts ? 'search-results' : 'search-no-results';
  } elseif (is_404()) {
    $slug = 'error404';
  }
  return $slug;
}

/*********************************
  編集画面カスタムカラー追加
 **********************************/
add_theme_support('editor-color-palette', [
  [
    'name'  => 'Gold',
    'slug'  => 'gold',
    'color' => '#877b61',
  ],
  [
    'name'  => 'Light Gold',
    'slug'  => 'light-gold',
    'color' => '#c1b396',
  ],
  [
    'name'  => 'Gray',
    'slug'  => 'gray',
    'color' => '#aaaaaa',
  ],
  [
    'name'  => 'Light Gray',
    'slug'  => 'light-gray',
    'color' => '#f7f7f7',
  ],
  [
    'name'  => 'Black',
    'slug'  => 'black',
    'color' => '#222222',
  ],
  [
    'name'  => 'White',
    'slug'  => 'white',
    'color' => '#ffffff',
  ],
]);


/*********************************
  エディタ内：必要なブロックのみ選択して表示
 **********************************/
add_filter('allowed_block_types', 'custom_allowed_block_types');
function custom_allowed_block_types($allowed_block_types)
{
  $allowed_block_types = [
    // 一般ブロック
    'core/paragraph',           // 段落
    'core/heading',             // 見出し
    'core/image',               // 画像
    'core/quote',               // 引用
    'core/gallery',             // ギャラリー
    'core/list',                // リスト
    'core/audio',               // 音声
    'core/cover',               // カバー
    'core/file',                // ファイル
    'core/video',               // 動画

    // フォーマット
    'core/code',                // ソースコード
    'core/freeform',            // クラシック
    'core/html',                // カスタムHTML
    'core/preformatted',        // 整形済み
    'core/pullquote',           // プルクオート
    'core/table',               // テーブル
    'core/verse',               // 詩

    // レイアウト要素
    'core/button',              // ボタン
    'core/columns',             // カラム
    'core/media-text',          // メディアと文章
    'core/more',                // 続きを読む
    'core/nextpage',            // 改ページ
    'core/separator',           // 区切り
    'core/spacer',              // スペーサー

    // ウィジェット
    'core/shortcode',           // ショートコード
    'core/archives',            // アーカイブ
    'core/categories',          // カテゴリー
    'core/latest-comments',     // 最新のコメント
    'core/latest-posts',        // 最新の記事

    // 埋め込み
    'core/embed',               // 埋め込み
    'core-embed/twitter',       // Twitter
    'core-embed/youtube',       // YouTube
    'core-embed/facebook',      // Facebook
    'core-embed/instagram',     // Instagram
    'core-embed/wordpress',     // WordPress
    'core-embed/soundcloud',    // SoundCloud
    'core-embed/spotify',       // Spotify
    'core-embed/flickr',        // Flickr
    'core-embed/vimeo',         // Viemo
    'core-embed/animoto',       // Animoto
    'core-embed/cloudup',       // Cloudup
    'core-embed/collegehumor',  // CollegeHumor
    'core-embed/dailymotion',   // Dailymotion
    'core-embed/funnyordie',    // Funny or Die
    'core-embed/hulu',          // Hulu
    'core-embed/imgur',         // Imgur
    'core-embed/issuu',         // Issuu
    'core-embed/kickstarter',   // Kickstarter
    'core-embed/meetup-com',    // Meetup.com
    'core-embed/mixcloud',      // Mixcloud
    'core-embed/photobucket',   // Photobucket
    'core-embed/polldaddy',     // Polldaddy
    'core-embed/reddit',        // Reddit
    'core-embed/reverbnation',  // ReverbNation
    'core-embed/screencast',    // Screencast
    'core-embed/scribd',        // Scribd
    'core-embed/slideshare',    // Slideshare
    'core-embed/smugmug',       // SmugMug
    'core-embed/speaker-deck',  // Speaker Deck
    'core-embed/ted',           // TED
    'core-embed/tumblr',        // Tumblr
    'core-embed/videopress',    // VideoPress
    'core-embed/wordpress-tv',  // WordPress.tv

    // 再利用ブロック
    'core/block',               // 再利用ブロック
  ];
  return $allowed_block_types;
}

/*********************************
  アーカイブタイトル取得関数から余計な文字を除外
 **********************************/
add_filter('get_the_archive_title', function ($title) {
  if (is_category()) {
    $title = single_cat_title('', false);
  } elseif (is_tag()) {
    $title = single_tag_title('', false);
  } elseif (is_tax()) {
    $title = single_term_title('', false);
  } elseif (is_post_type_archive()) {
    $title = post_type_archive_title('', false);
  } elseif (is_date()) {
    $title = get_the_time('Y年n月');
  } elseif (is_search()) {
    $title = '検索結果：' . esc_html(get_search_query(false));
  } elseif (is_404()) {
    $title = '「404」ページが見つかりません';
  } else {
  }
  return $title;
});

/*********************************
  メインループの条件変更
 **********************************/
function main_query_control($query)
{
  if (is_admin() || !$query->is_main_query()) {
    return;
  }
  if ($query->is_home()) {
    $query->set('ignore_sticky_posts', true);
    return;
  }
}
add_action('pre_get_posts', 'main_query_control');


/*********************************
  contactForm7 メールアドレス確認
 **********************************/
// add_filter('wpcf7_validate_email', 'wpcf7_validate_email_filter_extend', 11, 2);
// add_filter('wpcf7_validate_email*', 'wpcf7_validate_email_filter_extend', 11, 2);
// function wpcf7_validate_email_filter_extend($result, $tag)
// {
//   $type = $tag['type'];
//   $name = $tag['name'];
//   $_POST[$name] = trim(strtr((string) $_POST[$name], "n", " "));
//   if ('email' == $type || 'email*' == $type) {
//     if (preg_match('/(.*)_confirm$/', $name, $matches)) { //確認用メルアド入力フォーム名を ○○○_confirm としています。
//       $target_name = $matches[1];
//       if ($_POST[$name] != $_POST[$target_name]) {
//         if (method_exists($result, 'invalidate')) {
//           $result->invalidate($tag, "確認用のメールアドレスが一致していません");
//         } else {
//           $result['valid'] = false;
//           $result['reason'][$name] = '確認用のメールアドレスが一致していません';
//         }
//       }
//     }
//   }
//   return $result;
// }
